#
# spec file for package python-shinyutils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-shinyutils
Version:        12.4.0
Release:        1.3
Summary:        Various utilities for Python
License:        MIT
URL:            https://github.com/jayanthkoushik/shinyutils
Source:         https://files.pythonhosted.org/packages/source/s/shinyutils/shinyutils-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-crayons
Requires:       python-matplotlib
Requires:       python-seaborn
Recommends:     python-black
Recommends:     python-isort
Recommends:     python-twine
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module black}
BuildRequires:  %{python_module crayons}
BuildRequires:  %{python_module isort}
BuildRequires:  %{python_module matplotlib}
BuildRequires:  %{python_module pylint}
BuildRequires:  %{python_module seaborn}
BuildRequires:  %{python_module twine}
BuildRequires:  %{python_module wheel}
# /SECTION
%python_subpackages

%description
This package contains utilities for tasks in Python, including
matplotlib, subclasses, argument parsing, and logging.

%prep
%setup -q -n shinyutils-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%doc README.md CHANGELOG.md
%license LICENSE
%exclude %{python_sitelib}/CHANGELOG.md
%{python_sitelib}/shinyutils
%{python_sitelib}/shinyutils-%{version}.dist-info

%changelog
* Sun Jan 21 2024 Dirk Müller <dmueller@suse.com>
- update to 12.4.0:
  * raise `TypeError` if `SH` instance re-entered
  * handle single command case in `run_prog`
  * handle single unnamed command case in `run_prog`
  * allow `run_prog` to run without sub-parsers for single
    command programs
  * add `add_short_full_helps` argument to `run_prog`
  * add `run_prog` function
  * add more arguments to `run_prog`
  * allow specifying sub-commands with keyword arguments in
    `run_prog`
  * apply `add_short_full_helps` to subparsers in `run_prog`
  * use `corgy 4.1` to support Python 3.7 and 3.8
  * fix mock `trange` implementation
  * update `corgy` to version 4.0
  * simplify `NNTrainer` var names
  * refactor `pt` based on latest `corgy`
  * call `MatWrap.configure` in `PlottingArgs.__init__`
  * mark wrapped names in `matwrap` as `Any` so `mypy` doesn't
    complain
  * refactor `pt` based on latest `corgy`
  * simplify `NNTrainer` var names
  * update `corgy` to version 2.4
  * refactor `pt` to work better with `Corgy`
  * make `MatWrap.mpl/plt/sns` properties
  * replace `MatWrap.add_plotting_args` with `PlottingArgs` class
  * disalbe auto calling `conf_logging` and add parse arguments
    for it
  * remove logng.build_log_argp
  * make arguments to conf_logging keyword only
  * rename 'color' dependency group to 'colors'
  * remove plotting and pytorch dependency groups
  * increase minimum Python version to 3.9
  * add helps for argparse arguments
  * make `MatWrap.mpl/plt/sns` properties
  * make arguments to conf_logging keyword only
  * refactor `pt` to work better with `Corgy`
  * replace `MatWrap.add_plotting_args` with `PlottingArgs` class
  * allow passing callback function to NNTrainer
  * add sh module
  * make matwrap.Plot save_file argument optional
* Wed Jul 14 2021 Dominique Leuenberger <dimstar@opensuse.org>
- No longer build for python 3.6, as needed dependencies are not
  available (matplotlib, seaborn).
* Tue Dec  3 2019 Todd R <toddrme2178@gmail.com>
- initial version
